import contextlib
import os


@contextlib.contextmanager
def different_cwd(x):
    d = os.getcwd()

    # This could raise an exception, but it's probably
    # best to let it propagate and let the caller
    # deal with it, since they requested x
    os.chdir(x)

    try:
        yield

    finally:
        # This could also raise an exception, but you *really*
        # aren't equipped to figure out what went wrong if the
        # old working directory can't be restored.
        os.chdir(d)



import sys
from pathlib import Path

import pytest
from ccpn_project_checker.util import different_cwd
def run_tests():
    test_path = (Path('__file__').parent.resolve() / 'tests')
    retcode = pytest.main(['-x', test_path,'-vvv'])
    sys.exit(retcode)

if __name__ == '__main__':
    run_tests()